@@ -1,7 +1,7 @@
 /* -*- Mode: C; tab-width: 4; indent-tabs-mode: t; c-basic-offset: 4 -*- */
 /* ghex.h - defines GHex ;)
 
-   Copyright (C) 1998 - 2001 Free Software Foundation
+   Copyright (C) 1998 - 2002 Free Software Foundation
 
    GHex is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License as
@@ -21,53 +21,47 @@
    Author: Jaka Mocnik <jaka@gnu.org>
 */
 
-#ifndef GHEX_H
-#define GHEX_H
+#ifndef __GHEX_H__
+#define __GHEX_H__
+
 #include <config.h>
 #include <gnome.h>
 
 #include <libgnomeprint/gnome-print.h>
-#include <libgnomeprint/gnome-printer.h>
-#include <libgnomeprint/gnome-print-preview.h>
+
 #include <libgnomeprint/gnome-print-master.h>
 
 #include <stdio.h>
 
 #include "hex-document.h"
 #include "gtkhex.h"
+#include "ghex-marshal.h"
+#include "ghex-window.h"
+
+G_BEGIN_DECLS
 
 #define NO_BUFFER_LABEL "No buffer"
 
-#define DEFAULT_FONT    "-adobe-courier-medium-r-normal--12-*-*-*-*-*-*-*"
-
 #define MAX_MAX_UNDO_DEPTH 100000
 
 #define MESSAGE_LEN 512
 
-extern GnomeUIInfo help_menu[], file_menu[], view_menu[],
-	               main_menu[], tools_menu[];
-
 #define DATA_TYPE_HEX   0
 #define DATA_TYPE_ASCII 1
 
 #define NUM_MDI_MODES 4
 
-#define CHILD_MENU_PATH      "_File"
-#define CHILD_LIST_PATH      "Fi_les/"
-#define GROUP_MENU_PATH      "_Edit/_Group Data As/"
-#define OVERWRITE_ITEM_PATH  "_Edit/_Insert mode"
-
 #define GHEX_URL "http://pluton.ijs.si/~jaka/gnome.html#GHEX"
 
 typedef struct _PropertyUI {
-	GnomePropertyBox *pbox;
-	GtkRadioButton *mdi_type[NUM_MDI_MODES];
+	GtkWidget *pbox;
 	GtkRadioButton *group_type[3];
 	GtkWidget *font_button, *undo_spin, *box_size_spin;
 	GtkWidget *offset_menu, *offset_choice[3];
 	GtkWidget *format, *offsets_col;
 	GtkWidget *paper_sel, *print_font_sel;
 	GtkWidget *df_button, *hf_button;
+	GtkWidget *df_label, *hf_label;
 	GnomeFont *data_font, *header_font;
 } PropertyUI;
 
@@ -88,6 +82,9 @@ typedef struct _ReplaceDialog {
 
 typedef struct _FindDialog {
 	GtkWidget *window;
+	GtkWidget *frame;
+	GtkWidget *vbox;
+	GtkWidget *hbox;
 	GtkWidget *f_string;
 	GtkWidget *f_next, *f_prev, *f_close;
 	GtkWidget *type_button[2];
@@ -107,7 +104,8 @@ typedef struct _Converter {
 typedef struct {
 	GnomePrintMaster *master;
 	GnomePrintContext *pc;
-	GnomePrinter *printer;
+	GnomePrintConfig *config;
+
 	GnomeFont *d_font, *h_font;
 	HexDocument *doc;
 
@@ -115,17 +113,17 @@ typedef struct {
 	gint range;
 	gint page_first;
 	gint page_last;
-	float page_width, page_height;
-	float margin_top, margin_bottom, margin_left, margin_right;
-	float printable_width, printable_height;
+	gdouble page_width, page_height;
+	gdouble margin_top, margin_bottom, margin_left, margin_right;
+	gdouble printable_width, printable_height;
 
-	float header_height;
+	gdouble header_height;
 	
-	float font_char_width;
-	float font_char_height;
+	gdouble font_char_width;
+	gdouble font_char_height;
 
 	int   bytes_per_row, rows_per_page;
-	float pad_size;
+	gdouble pad_size;
 	int   offset_chars ; /* How many chars are used in the offset window */
 	int   gt;            /* group_type */
 	gboolean preview;
@@ -135,7 +133,6 @@ extern int restarted;
 extern const struct poptOption options[];
 extern GSList *cl_files;
 
-extern GnomeMDI       *mdi;
 extern GtkWidget      *file_sel;
 extern FindDialog     *find_dialog;
 extern ReplaceDialog  *replace_dialog;
@@ -146,27 +143,27 @@ extern PropertyUI     *prefs_ui;
 
 /* our preferred settings; as only one copy of them is required,
    we'll make them global vars, although this is a bit ugly */
-extern GdkFont    *def_font;
+extern PangoFontMetrics *def_metrics;
+extern PangoFontDescription *def_font_desc;
+
 extern gchar      *def_font_name;
 extern gchar      *data_font_name, *header_font_name;
 extern gdouble    data_font_size, header_font_size;    
 extern guint      max_undo_depth;
 extern gchar      *offset_fmt;
 extern gboolean   show_offsets_column;
-extern const GnomePaper *def_paper;
+
 extern gint       shaded_box_size;
 extern gint       def_group_type;
-extern gint       mdi_mode;
 
 extern guint group_type[3];
 extern gchar *group_type_label[3];
 
-extern guint mdi_type[NUM_MDI_MODES];
-extern gchar *mdi_type_label[NUM_MDI_MODES];
-
 extern guint search_type;
 extern gchar *search_type_label[2];
 
+extern gchar *geometry;
+
 /* creation of dialogs */
 FindDialog    *create_find_dialog    (void);
 ReplaceDialog *create_replace_dialog (void);
@@ -182,6 +179,8 @@ GtkWidget *create_button   (GtkWidget *, const gchar *, gchar *);
 
 /* printing */
 void ghex_print_job_execute(GHexPrintJobInfo *pji);
+void ghex_print_update_page_size_and_margins (HexDocument *doc, GHexPrintJobInfo *pji);
+
 GHexPrintJobInfo *ghex_print_job_info_new(HexDocument *doc, guint group_type);
 void ghex_print_job_info_destroy(GHexPrintJobInfo *pji);
 
@@ -194,15 +193,47 @@ gint delete_event_cb(GtkWidget *, GdkEventAny *);
 void cancel_cb(GtkWidget *, GtkWidget *);
 
 /* session managment */
-int save_state      (GnomeClient        *client,
-                     gint                phase,
-                     GnomeRestartStyle   save_style,
-                     gint                shutdown,
-                     GnomeInteractStyle  interact_style,
-                     gint                fast,
-                     gpointer            client_data);
+gint
+save_session    (GnomeClient        *client,
+				 gint                phase,
+				 GnomeRestartStyle   save_style,
+				 gint                shutdown,
+				 GnomeInteractStyle  interact_style,
+				 gint                fast,
+				 gpointer            client_data);
+void client_die (GnomeClient *client, gpointer client_data);
 
-gint client_die     (GnomeClient *client, gpointer client_data);
+extern BonoboUIVerb ghex_verbs [];
 
+/* Defined in converter.c: used by close_cb and converter_cb */
+extern GtkWidget *converter_get;
 
-#endif
+/* Initializes the gconf client */
+void ghex_prefs_init (void);
+
+void find_cb (BonoboUIComponent *uic, gpointer user_data, const gchar* verbname);
+void replace_cb (BonoboUIComponent *uic, gpointer user_data, const gchar* verbname);
+void jump_cb (BonoboUIComponent *uic, gpointer user_data, const gchar* verbname);
+void set_byte_cb (BonoboUIComponent *uic, gpointer user_data, const gchar* verbname);
+void set_word_cb (BonoboUIComponent *uic, gpointer user_data, const gchar* verbname);
+void set_long_cb (BonoboUIComponent *uic, gpointer user_data, const gchar* verbname);
+void undo_cb (BonoboUIComponent *uic, gpointer user_data, const gchar* verbname);
+void redo_cb (BonoboUIComponent *uic, gpointer user_data, const gchar* verbname);
+void add_view_cb (BonoboUIComponent *uic, gpointer user_data, const gchar* verbname);
+void remove_view_cb (BonoboUIComponent *uic, gpointer user_data, const gchar* verbname);
+void insert_cb (BonoboUIComponent *uic, gpointer user_data, const gchar* verbname);
+void quit_app_cb (BonoboUIComponent *uic, gpointer user_data, const gchar* verbname);
+void file_list_activated_cb (BonoboUIComponent *uic, gpointer user_data, const gchar* verbname);
+
+void display_error_dialog (GHexWindow *win, const gchar *msg);
+void display_info_dialog (GHexWindow *win, const gchar *msg, ...);
+void update_dialog_titles (void);
+void raise_and_focus_widget(GtkWidget *);
+
+gboolean hex_document_ok_to_close(HexDocument *doc);
+
+void set_prefs(PropertyUI *pui);
+
+G_END_DECLS
+
+#endif /* __GHEX_H__ */
